@@ -14,6 +14,8 @@ context("Testing bcdc_get_citation function")
 
 
 test_that("bcdc_get_citation take a character and returns a bibentry",{
+  skip_if_net_down()
+  skip_on_cran()
   rec <- bcdc_get_record(point_record)
   expect_s3_class(bcdc_get_citation(rec), c("citation", "bibentry"))
   expect_s3_class(bcdc_get_citation(point_record), c("citation", "bibentry"))
