@@ -11,10 +11,9 @@ test_that("recods with wms but inconsistent layer_name, object_name fields work"
 
   # https://github.com/bcgov/bcdata/issues/129
   # layer_name = WHSE_ADMIN_BOUNDARIES.ADM_NR_DISTRICTS_SPG
-  # object_name = WHSE_ADMIN_BOUNDARIES.ADM_NR_DISTRICTS_SP
   # wms uses layer_name (generalized)
-  expect_warning(
+  expect_message(
     expect_is(bcdc_query_geodata("natural-resource-nr-district"), "bcdc_promise"),
-    "The name of the object available through the web service"
+    "You are accessing a simplified view of the data"
   )
 })
